@@ -165,7 +165,11 @@ class DOMNode(MessagePump):
         self._auto_refresh: float | None = None
         self._auto_refresh_timer: Timer | None = None
         self._css_types = {cls.__name__ for cls in self._css_bases(self.__class__)}
-        self._bindings = self._merged_bindings or Bindings()
+        self._bindings = (
+            Bindings()
+            if self._merged_bindings is None
+            else self._merged_bindings.copy()
+        )
         self._has_hover_style: bool = False
         self._has_focus_within: bool = False
 
@@ -204,6 +208,11 @@ class DOMNode(MessagePump):
             )
         self._auto_refresh = interval
 
+    @property
+    def is_modal(self) -> bool:
+        """Is the node a modal?"""
+        return False
+
     def _automatic_refresh(self) -> None:
         """Perform an automatic refresh (set with auto_refresh property)."""
         self.refresh()
