@@ -5,6 +5,7 @@ from typing import Iterable, Iterator
 
 import rich.repr
 from rich.cells import cell_len, set_cell_size
+from rich.console import Console, ConsoleOptions, RenderResult
 from rich.segment import Segment
 from rich.style import Style, StyleType
 
@@ -27,6 +28,21 @@ def get_line_length(segments: Iterable[Segment]) -> int:
     return sum(_cell_len(text) for text, _, control in segments if not control)
 
 
+class StripRenderable:
+    """A renderable which renders a list of strips in to lines.."""
+
+    def __init__(self, strips: list[Strip]) -> None:
+        self._strips = strips
+
+    def __rich_console__(
+        self, console: Console, options: ConsoleOptions
+    ) -> RenderResult:
+        new_line = Segment.line()
+        for strip in self._strips:
+            yield from strip
+            yield new_line
+
+
 @rich.repr.auto
 class Strip:
     """Represents a 'strip' (horizontal line) of a Textual Widget.
