@@ -13,7 +13,7 @@ from rich.protocol import is_renderable
 from rich.segment import Segment
 from rich.style import Style
 from rich.text import Text, TextType
-from typing_extensions import Literal, TypeAlias
+from typing_extensions import Literal, Self, TypeAlias
 
 from .. import events
 from .._cache import LRUCache
@@ -29,14 +29,13 @@ from ..reactive import Reactive
 from ..render import measure
 from ..scroll_view import ScrollView
 from ..strip import Strip
+from ..widget import PseudoClasses
 
-CellCacheKey: TypeAlias = "tuple[RowKey, ColumnKey, Style, bool, bool, int]"
-LineCacheKey: TypeAlias = (
-    "tuple[int, int, int, int, Coordinate, Coordinate, Style, CursorType, bool, int]"
-)
-RowCacheKey: TypeAlias = (
-    "tuple[RowKey, int, Style, Coordinate, Coordinate, CursorType, bool, bool, int]"
+CellCacheKey: TypeAlias = (
+    "tuple[RowKey, ColumnKey, Style, bool, bool, int, PseudoClasses]"
 )
+LineCacheKey: TypeAlias = "tuple[int, int, int, int, Coordinate, Coordinate, Style, CursorType, bool, int, PseudoClasses]"
+RowCacheKey: TypeAlias = "tuple[RowKey, int, Style, Coordinate, Coordinate, CursorType, bool, bool, int, PseudoClasses]"
 CursorType = Literal["cell", "row", "column", "none"]
 CellType = TypeVar("CellType")
 
@@ -247,6 +246,8 @@ class DataTable(ScrollView, Generic[CellType], can_focus=True):
     DataTable {
         background: $surface ;
         color: $text;
+        height: auto;
+        max-height: 100vh
     }
     DataTable > .datatable--header {
         text-style: bold;
@@ -608,6 +609,11 @@ class DataTable(ScrollView, Generic[CellType], can_focus=True):
         self._ordered_row_cache: LRUCache[tuple[int, int], list[Row]] = LRUCache(1)
         """Caches row ordering - key is (num_rows, update_count)."""
 
+        self._pseudo_class_state = PseudoClasses(False, False, False)
+        """The pseudo-class state is used as part of cache keys to ensure that, for example,
+        when we lose focus on the DataTable, rules which apply to :focus are invalidated
+        and we prevent lingering styles."""
+
         self._require_update_dimensions: bool = False
         """Set to re-calculate dimensions on idle."""
         self._new_rows: set[RowKey] = set()
@@ -1156,11 +1162,14 @@ class DataTable(ScrollView, Generic[CellType], can_focus=True):
         full_column_region = Region(x, 0, width, height)
         return full_column_region
 
-    def clear(self, columns: bool = False) -> None:
+    def clear(self, columns: bool = False) -> Self:
         """Clear the table.
 
         Args:
-            columns: Also clear the columns. Defaults to False.
+            columns: Also clear the columns.
+
+        Returns:
+            The `DataTable` instance.
         """
         self._clear_caches()
         self._y_offsets.clear()
@@ -1176,6 +1185,7 @@ class DataTable(ScrollView, Generic[CellType], can_focus=True):
         self._label_column = Column(self._label_column_key, Text(), auto_width=True)
         self._labelled_row_exists = False
         self.refresh()
+        return self
 
     def add_column(
         self, label: TextType, *, width: int | None = None, key: str | None = None
@@ -1333,49 +1343,66 @@ class DataTable(ScrollView, Generic[CellType], can_focus=True):
             self._updated_cells.clear()
             self._update_column_widths(updated_columns)
 
-    def refresh_coordinate(self, coordinate: Coordinate) -> None:
+    def refresh_coordinate(self, coordinate: Coordinate) -> Self:
         """Refresh the cell at a coordinate.
 
         Args:
             coordinate: The coordinate to refresh.
+
+        Returns:
+            The `DataTable` instance.
         """
         if not self.is_valid_coordinate(coordinate):
-            return
+            return self
         region = self._get_cell_region(coordinate)
         self._refresh_region(region)
+        return self
 
-    def refresh_row(self, row_index: int) -> None:
+    def refresh_row(self, row_index: int) -> Self:
         """Refresh the row at the given index.
 
         Args:
             row_index: The index of the row to refresh.
+
+        Returns:
+            The `DataTable` instance.
         """
         if not self.is_valid_row_index(row_index):
-            return
+            return self
 
         region = self._get_row_region(row_index)
         self._refresh_region(region)
+        return self
 
-    def refresh_column(self, column_index: int) -> None:
+    def refresh_column(self, column_index: int) -> Self:
         """Refresh the column at the given index.
 
         Args:
             column_index: The index of the column to refresh.
+
+        Returns:
+            The `DataTable` instance.
         """
         if not self.is_valid_column_index(column_index):
-            return
+            return self
 
         region = self._get_column_region(column_index)
         self._refresh_region(region)
+        return self
 
-    def _refresh_region(self, region: Region) -> None:
-        """Refresh a region of the DataTable, if it's visible within
-        the window. This method will translate the region to account
-        for scrolling."""
+    def _refresh_region(self, region: Region) -> Self:
+        """Refresh a region of the DataTable, if it's visible within the window.
+
+        This method will translate the region to account for scrolling.
+
+        Returns:
+            The `DataTable` instance.
+        """
         if not self.window_region.overlaps(region):
-            return
+            return self
         region = region.translate(-self.scroll_offset)
         self.refresh(region)
+        return self
 
     def is_valid_row_index(self, row_index: int) -> bool:
         """Return a boolean indicating whether the row_index is within table bounds.
@@ -1536,7 +1563,15 @@ class DataTable(ScrollView, Generic[CellType], can_focus=True):
             row_key = self._row_locations.get_key(row_index)
 
         column_key = self._column_locations.get_key(column_index)
-        cell_cache_key = (row_key, column_key, style, cursor, hover, self._update_count)
+        cell_cache_key = (
+            row_key,
+            column_key,
+            style,
+            cursor,
+            hover,
+            self._update_count,
+            self._pseudo_class_state,
+        )
 
         if cell_cache_key not in self._cell_render_cache:
             style += Style.from_meta({"row": row_index, "column": column_index})
@@ -1592,6 +1627,7 @@ class DataTable(ScrollView, Generic[CellType], can_focus=True):
             show_cursor,
             self._show_hover_cursor,
             self._update_count,
+            self._pseudo_class_state,
         )
 
         if cache_key in self._row_render_cache:
@@ -1764,6 +1800,7 @@ class DataTable(ScrollView, Generic[CellType], can_focus=True):
             self.cursor_type,
             self._show_hover_cursor,
             self._update_count,
+            self._pseudo_class_state,
         )
         if cache_key in self._line_cache:
             return self._line_cache[cache_key]
@@ -1788,6 +1825,10 @@ class DataTable(ScrollView, Generic[CellType], can_focus=True):
         self._line_cache[cache_key] = strip
         return strip
 
+    def render_lines(self, crop: Region) -> list[Strip]:
+        self._pseudo_class_state = self.get_pseudo_class_state()
+        return super().render_lines(crop)
+
     def render_line(self, y: int) -> Strip:
         width, height = self.size
         scroll_x, scroll_y = self.scroll_offset
@@ -1820,6 +1861,9 @@ class DataTable(ScrollView, Generic[CellType], can_focus=True):
             except KeyError:
                 pass
 
+    def on_leave(self, event: events.Leave) -> None:
+        self._set_hover_cursor(False)
+
     def _get_fixed_offset(self) -> Spacing:
         """Calculate the "fixed offset", that is the space to the top and left
         that is occupied by fixed rows and columns respectively. Fixed rows and columns
@@ -1839,12 +1883,15 @@ class DataTable(ScrollView, Generic[CellType], can_focus=True):
         self,
         *columns: ColumnKey | str,
         reverse: bool = False,
-    ) -> None:
-        """Sort the rows in the DataTable by one or more column keys.
+    ) -> Self:
+        """Sort the rows in the `DataTable` by one or more column keys.
 
         Args:
             columns: One or more columns to sort by the values in.
             reverse: If True, the sort order will be reversed.
+
+        Returns:
+            The `DataTable` instance.
         """
 
         def sort_by_column_keys(
@@ -1862,6 +1909,7 @@ class DataTable(ScrollView, Generic[CellType], can_focus=True):
         )
         self._update_count += 1
         self.refresh()
+        return self
 
     def _scroll_cursor_into_view(self, animate: bool = False) -> None:
         """When the cursor is at a boundary of the DataTable and moves out
